@@ -2,19 +2,25 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakter",
+    "Address book name" : "Adressebogsnavn",
     "No contacts in here" : "Ingen kontaktpersoner her",
     "Name" : "Navn",
     "Organization" : "Organisation",
     "Title" : "Titel",
     "Add field ..." : "Tilføj felt...",
+    "Import" : "Importér",
     "Add contact" : "Tilføj kontaktpeson.",
+    "No search result for {query}" : "Ingen søgeresultater for  {query}",
     "All contacts" : "Alle kontakter",
     "Not grouped" : "Ikke i gruppe",
+    "Post Office Box" : "Postboks",
     "Postal Code" : "Postnummer",
     "City" : "By",
     "State or province" : "Stat eller provins",
     "Country" : "Land",
     "Address" : "Adresse",
+    "(new group)" : "(new group)",
+    "New contact" : "Ny kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
     "Nickname" : "Kaldenavn",
     "Notes" : "Noter",
@@ -34,7 +40,6 @@ OC.L10N.register(
     "Fax work" : "Fax arbejde",
     "Pager" : "Personsøger",
     "Voice" : "Telefonsvarer",
-    "Settings" : "Indstillinger",
-    "Import" : "Importér"
+    "Settings" : "Indstillinger"
 },
 "nplurals=2; plural=(n != 1);");
