@@ -22,7 +22,7 @@ OC.L10N.register(
     "(new group)" : "(new group)",
     "New contact" : "New contact",
     "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
-    "Invalid file type." : "Invalid file type.",
+    "No contacts in file. Only VCard files are allowed." : "No contacts in file. Only VCard files are allowed.",
     "Nickname" : "Nickname",
     "Notes" : "Notes",
     "Website" : "Website",
