@@ -37,11 +37,7 @@ vendor_style('select2/select2');
 			</div>
 			<div id="app-settings-content">
 				<addressBookList></addressBookList>
-				<input type="file" id="contact-import" class="hidden-visually" contactimport />
-				<label for="contact-import" class="button" id="upload">
-					<?php p($l->t('Import'));?>
-					<span class="icon-upload"></span>
-				</label>
+				<contactImport></contactImport>
 			</div>
 		</div>
 	</div>
